Index: /trunk/FACT++/scripts/doc/dim.js
===================================================================
--- /trunk/FACT++/scripts/doc/dim.js	(revision 14971)
+++ /trunk/FACT++/scripts/doc/dim.js	(revision 14972)
@@ -30,8 +30,8 @@
  *
  * @example
- *     dim.print("Five="+5, "--- new line ---");
+ *     dim.log("Five="+5, "--- new line ---");
  *
  */
-dim.print = function() { /* [native code] */ }
+dim.log = function() { /* [native code] */ }
 
 /**
@@ -39,5 +39,5 @@
  * Posts a message to the dim network with alarm severity.
  *
  * Similar to dim.print, but the message is posted to the network
  * with alarm severity. This means that it is displayed in red
  * and the smartfact web-gui will play an alarm sound.
@@ -39,5 +39,5 @@
  * Posts a message to the dim network with alarm severity.
  *
- * Similar to dim.print, but the message is posted to the network
+ * Similar to dim.log, but the message is posted to the network
  * with alarm severity. This means that it is displayed in red
  * and the smartfact web-gui will play an alarm sound.
